@@ -33,8 +33,18 @@ class MySQLPipeline:
         self.db.close()
 
     def process_item(self, item, spider):
-        data = item
         data = dict(item)
+        if data.get("title", None):  # brand_id :: 出去型号两边空格
+            data["title"] = data["title"].strip()
+        if data.get("sources", None):  # sources :: 出去sources两边空格
+            data["sources"] = data["sources"].strip()
+        if data.get("brand_name", None):  # brand_name :: 出去品牌两边空格
+            data["brand_name"] = data["brand_name"].strip()
+        if data.get("category_id", None):  # category_id :: 出去category_id两边空格
+            data["category_id"] = data["category_id"].strip()
+        if data.get("list_json", None):  # list_json :: 出去category_id两边空格
+            if isinstance(data["list_json"],dict):
+                data["list_json"] =json.dumps(data["list_json"])
         keys = ', '.join(data.keys())
         values = ', '.join(['% s'] * len(data))
         sql = 'insert into % s (% s) values (% s)' % (item.table, keys, values)
