@@ -165,7 +165,10 @@ class OssFilesPipeline(MediaPipeline):
         self.filter_empty_item = settings.get(
             'FILTER_EMPTY_ITEM', self.FILTER_EMPTY_ITEM
         )
-
+        self.invalid_fild_path = settings.get(
+            #invalid_file_body
+            'FILTER_INVALID_FILE_PATH', False
+        )
         self.page_logo_text = settings.get('FILE_PIPE_CONFIG').get(self.__class__.__name__).get('PAGE_LOGO_TEXT',None)
         self.item_header_dict = settings.get('FILE_PIPE_CONFIG').get(self.__class__.__name__).get('ITEM_HEADER',None)
         self.files_oss_file = settings.get('FILE_PIPE_CONFIG').get(self.__class__.__name__).get('FILES_OSS_FILE')
@@ -206,8 +209,12 @@ class OssFilesPipeline(MediaPipeline):
 
     def media_downloaded(self, response, request, info, *, item=None): # 判断是否正常资源
         referer = referer_str(request)
-        
-
+        if self.invalid_fild_path:
+            # invalid_fild_path :: 失效文件路径,表示遇到该文件结果字段如pdf_url就返回空
+            with open(f"{self.invalid_fild_path}",'rb') as f:
+                invalid_file_body = f.read()
+            if invalid_file_body == response.body:
+                return {'url': request.url, 'path': ''}
         if response.status != 200:
             logger.warning(
                 'File (code: %(status)s): Error downloading file from '
